StorePrice class

Localized and numeric Microsoft Store price information.

Constructors

StorePrice({String? currencyCode, String? formattedBasePrice, String? formattedPrice, String? formattedRecurrencePrice, double? unformattedBasePrice, double? unformattedPrice, double? unformattedRecurrencePrice, bool? isOnSale, DateTime? saleEndsAt})
Creates a Store price value.
const
StorePrice.fromJson(Map<String, dynamic> json)
Creates price information from a structured channel payload.
factory

Properties

currencyCode String?
ISO 4217 currency code.
final
formattedBasePrice String?
Localized undiscounted price.
final
formattedPrice String?
Localized current purchase price.
final
formattedRecurrencePrice String?
Localized recurring subscription price.
final
hashCode int
The hash code for this object.
no setterinherited
isOnSale bool?
Whether the product is currently on sale.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
saleEndsAt DateTime?
UTC sale end time, when the price is promotional.
final
unformattedBasePrice double?
Numeric undiscounted price.
final
unformattedPrice double?
Numeric current purchase price.
final
unformattedRecurrencePrice double?
Numeric recurring subscription price.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts this price to a JSON-compatible map.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited