checkPurchase method

Future<bool> checkPurchase({
  1. String storeId = '',
})

Performs a best-effort client-side entitlement check.

Microsoft Store add-on StoreLicense.isActive is not used because the native property currently always returns true. A license must be present in AddOnLicenses and its UTC expiration time must still be in the future. An empty storeId checks whether any add-on is currently entitled.

For authoritative auto-renewal, refund, revocation and dunning state, verify the subscription with Microsoft's server-side Recurrence API.

Implementation

Future<bool> checkPurchase({String storeId = ''}) {
  _ensureWindows();
  return WindowsIapPlatform.instance.checkPurchase(
    storeId: storeId.trim(),
  );
}