WindowsIapPlatform class abstract

Contract implemented by platform-specific windows_store_iap backends.

Inheritance
  • Object
  • PlatformInterface
  • WindowsIapPlatform
Implementers

Constructors

WindowsIapPlatform()
Constructs a WindowsIapPlatform.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

checkPurchase({required String storeId}) Future<bool>
Checks a client-side add-on entitlement for storeId.
getAddonLicenses() Future<Map<String, StoreLicense>>
Returns the current add-on license collection.
getAppLicense() Future<StoreAppLicense>
Returns the current application license and add-on licenses.
getProducts() Future<List<Product>>
Returns products associated with the current Store application.
makePurchase(String storeId) Future<StorePurchaseStatus?>
Opens the Store purchase UI for storeId.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance WindowsIapPlatform
The default instance of WindowsIapPlatform to use.
getter/setter pair