StoreAppLicense class
License information for the current Store application and its add-ons.
Constructors
-
StoreAppLicense({required bool isActive, required bool isTrial, String? skuStoreId, DateTime? expiresAt, Duration? trialTimeRemaining, String? trialUniqueId, String? extendedJsonData, Map<
String, StoreLicense> addOnLicenses = const {}}) -
Creates an application license value.
const
-
StoreAppLicense.fromJson(Map<
String, dynamic> json) -
Creates an application license from a structured channel payload.
factory
Properties
-
addOnLicenses
→ Map<
String, StoreLicense> -
Add-on licenses keyed as returned by the Windows Store API.
final
- expiresAt → DateTime?
-
UTC application-license expiration time, when present.
final
- extendedJsonData → String?
-
Raw extended JSON supplied by Microsoft Store.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isActive → bool
-
Whether the application license is active.
final
- isTrial → bool
-
Whether the application is currently using a trial license.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- skuStoreId → String?
-
SKU Store ID associated with the application license.
final
- trialTimeRemaining → Duration?
-
Remaining trial duration, when the application is in a trial.
final
- trialUniqueId → String?
-
Microsoft Store identifier for the current trial.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Converts this license to a JSON-compatible map.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited