StoreAvailability class

A purchasable availability for a Microsoft Store SKU.

Constructors

StoreAvailability({String? storeId, DateTime? endsAt, StorePrice? price, String? extendedJsonData})
Creates a Store availability value.
const
StoreAvailability.fromJson(Map<String, dynamic> json)
Creates an availability from a structured channel payload.
factory

Properties

endsAt DateTime?
UTC time at which this availability ends, when defined.
final
extendedJsonData String?
Raw extended JSON supplied by Microsoft Store.
final
hashCode int
The hash code for this object.
no setterinherited
price StorePrice?
Price for this availability.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
storeId String?
Availability Store ID used for purchase selection.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts this availability to a JSON-compatible map.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited