StoreSubscriptionInfo class
Billing cadence and optional trial period for a subscription SKU.
Constructors
- StoreSubscriptionInfo({int? billingPeriod, StoreDurationUnit billingPeriodUnit = StoreDurationUnit.unknown, bool? hasTrialPeriod, int? trialPeriod, StoreDurationUnit trialPeriodUnit = StoreDurationUnit.unknown})
-
Creates subscription billing information.
const
-
StoreSubscriptionInfo.fromJson(Map<
String, dynamic> json) -
Creates subscription information from a structured channel payload.
factory
Properties
- billingPeriod → int?
-
Number of billingPeriodUnit units in each billing period.
final
- billingPeriodUnit → StoreDurationUnit
-
Unit used by billingPeriod.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasTrialPeriod → bool?
-
Whether the subscription has a trial period.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- trialPeriod → int?
-
Number of trialPeriodUnit units in the trial.
final
- trialPeriodUnit → StoreDurationUnit
-
Unit used by trialPeriod.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Converts this information to a JSON-compatible map.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited