MethodChannelWindowsIap class
MethodChannel implementation for Microsoft Store on Windows.
- Inheritance
-
- Object
- PlatformInterface
- WindowsIapPlatform
- MethodChannelWindowsIap
Constructors
- MethodChannelWindowsIap({MethodChannel methodChannel = const MethodChannel('windows_store_iap')})
- Creates a MethodChannel implementation.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- methodChannel → MethodChannel
-
Channel used to communicate with the Windows plugin.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
checkPurchase(
{required String storeId}) → Future< bool> -
Checks a client-side add-on entitlement for
storeId.override -
getAddonLicenses(
) → Future< Map< String, StoreLicense> > -
Returns the current add-on license collection.
override
-
getAppLicense(
) → Future< StoreAppLicense> -
Returns the current application license and add-on licenses.
override
-
getProducts(
) → Future< List< Product> > -
Returns products associated with the current Store application.
override
-
makePurchase(
String storeId) → Future< StorePurchaseStatus?> -
Opens the Store purchase UI for
storeId.override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited